import { classes } from '@automapper/classes';
import { AutomapperModule } from '@automapper/nestjs';
import { Module } from '@nestjs/common';
import { ConfigModule } from '@nestjs/config';
import { HealthModule } from './modules/health/health.module';
import { MatcherModule } from './modules/matcher/matcher.module';
import { AdModule } from './modules/ad/ad.module';
import { ConfigurationModule } from '@mobicoop/configuration-module';

@Module({
  imports: [
    ConfigModule.forRoot({ isGlobal: true }),
    ConfigurationModule.forRootAsync({
      setConfigurationBrokerRoutingKeys: [
        'configuration.create',
        'configuration.update',
      ],
      deleteConfigurationRoutingKey: 'configuration.delete',
      propagateConfigurationRoutingKey: 'configuration.propagate',
      setConfigurationBrokerQueue: 'matcher-configuration-create-update',
      deleteConfigurationQueue: 'matcher-configuration-delete',
      propagateConfigurationQueue: 'matcher-configuration-propagate',
    }),
    AutomapperModule.forRoot({ strategyInitializer: classes() }),
    HealthModule,
    MatcherModule,
    AdModule,
  ],
  controllers: [],
  providers: [],
})
export class AppModule {}
