import { Injectable } from '@nestjs/common';
import {
  HealthCheckError,
  HealthIndicator,
  HealthIndicatorResult,
} from '@nestjs/terminus';
import { AdRepository } from '../../../ad/adapters/secondaries/ad.repository';

@Injectable()
export class PrismaHealthIndicatorUseCase extends HealthIndicator {
  constructor(private readonly repository: AdRepository) {
    super();
  }

  isHealthy = async (key: string): Promise<HealthIndicatorResult> => {
    try {
      await this.repository.healthCheck();
      return this.getStatus(key, true);
    } catch (e) {
      throw new HealthCheckError('Prisma', {
        prisma: e.message,
      });
    }
  };
}
